# Capabilities

Capability registry for cutip-blocks. Each merged feature or fix is assigned a cap ID.

cutip-blocks capabilities start at **cap100** (cutip uses cap001–cap059, cutip-desktop uses cap030–cap062).

| ID | Title | Type | Status | Branch | PR | Date |
|----|-------|------|--------|--------|----|------|
| cap100 | Initial block library — 34 blocks across 9 categories | feat | merged | — | — | 2026-03-24 |
